@@ -1,6 +1,6 @@
 package Dist::Surveyor::Inquiry;
 {
-  $Dist::Surveyor::Inquiry::VERSION = '0.011';
+  $Dist::Surveyor::Inquiry::VERSION = '0.013';
 }
 use strict;
 use warnings;
@@ -20,7 +20,7 @@ Dist::Surveyor::Inquiry - Handling the meta-cpan API access for Dist::Surveyor
 
 =head1 VERSION
 
-version 0.011
+version 0.013
 
 =head1 DESCRIPTION
 
@@ -62,7 +62,11 @@ our ($DEBUG, $VERBOSE);
 *DEBUG = \$::DEBUG;
 *VERBOSE = \$::VERBOSE;
 
-my $ua = LWP::UserAgent->new( agent => $0, timeout => 10 );
+my $ua = LWP::UserAgent->new( 
+    agent => $0, 
+    timeout => 10,
+    keep_alive => 3, 
+);
 
 require Exporter;
 our @ISA = qw{Exporter};
